# -*- coding: utf-8 -*-

# RenderImageDialog.py
# This file is part of the Gedit LaTeX Plugin
#
# Copyright (C) 2006 Michael Zeising
#
# This program is free software; you can redistribute it and/or modify it under
# the terms of the GNU General Public Licence as published by the Free Software
# Foundation; either version 2 of the Licence, or (at your option) any later
# version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE.  See the GNU General Public Licence for more 
# details.
#
# You should have received a copy of the GNU General Public Licence along with
# this program; if not, write to the Free Software Foundation, Inc., 51 Franklin
# Street, Fifth Floor, Boston, MA  02110-1301, USA

import gtk
import const

PNG_MODES = [
		("mono", _("monochrome")),
		("gray", _("grayscale")),
		("16", _("RGB (4 bit)")),
		("256", _("RGB (8 bit)")),
		("16m", _("RGB (24 bit)")),
		("alpha", _("RGBA (transparent)"))
]

AA_FACTORS = [0, 1, 2, 4, 8]

class RenderImageDialog(gtk.Dialog):
	def __init__(self):
		gtk.Dialog.__init__(self, _("Render to Image"), None, gtk.DIALOG_MODAL | gtk.DIALOG_DESTROY_WITH_PARENT, 
				(gtk.STOCK_CANCEL, gtk.RESPONSE_CANCEL, gtk.STOCK_OK, gtk.RESPONSE_OK))
		self.set_border_width(5)
		self.set_has_separator(False)
		self.vbox.set_spacing(10)
		
		box = gtk.VBox()
		box.set_border_width(5)
		box.set_spacing(5)
		
		# PNG
		
		self._radio_png = gtk.RadioButton(None, "PNG")
		
		self._label_png = gtk.Label(_("Color mode:"))
		self._label_png.set_alignment(0, .5)
		self._combo_png = gtk.combo_box_new_text()
		for pair in PNG_MODES:
			self._combo_png.append_text(pair[1])
		self._combo_png.set_active(4)
		
		hbox_png = gtk.HBox()
		hbox_png.set_spacing(5)
		hbox_png.pack_start(self._label_png, False)
		hbox_png.pack_start(self._combo_png, False)
		
		align_png = gtk.Alignment(.5, .5, 1, 1)
		align_png.set_padding(0, 0, 20, 0)
		align_png.add(hbox_png)
		
		# JPEG, GIF
		
		self._radio_jpg = gtk.RadioButton(self._radio_png, "JPEG")
		self._radio_gif = gtk.RadioButton(self._radio_png, "GIF")
		
		vbox_format = gtk.VBox()
		vbox_format.set_spacing(2)
		vbox_format.add(self._radio_png)
		vbox_format.add(align_png)
		vbox_format.add(self._radio_jpg)
		vbox_format.add(self._radio_gif)
		
		align_format = gtk.Alignment(.5, .5, 1, 1)
		align_format.set_padding(5, 0, 15, 0)
		align_format.add(vbox_format)
		
		frame_format = gtk.Frame(_("<b>Image format</b>"))
		frame_format.get_label_widget().set_use_markup(True)
		frame_format.set_shadow_type(gtk.SHADOW_NONE)
		frame_format.add(align_format)
		
		box.add(frame_format)
		
		# AA
		
		label_aa = gtk.Label(_("Antialiasing factor:"))
		label_aa.set_alignment(0, .5)
		
		self._combo_aa = gtk.combo_box_new_text()
		for factor in AA_FACTORS:
			self._combo_aa.append_text(str(factor))
		self._combo_aa.set_active(3)
		
		label_res = gtk.Label(_("Resolution:"))
		label_res.set_alignment(0, .5)
		label_res_u = gtk.Label("dpi")
		label_res_u.set_alignment(0, .5)
		
		self._spin_res = gtk.SpinButton(gtk.Adjustment(120, 1, 999, 1), 1)
		
		hbox_quality = gtk.HBox()
		hbox_quality.set_spacing(10)
		hbox_quality.pack_start(label_aa, False)
		hbox_quality.pack_start(self._combo_aa, False)
		hbox_quality.pack_start(label_res, False)
		hbox_quality.pack_start(self._spin_res, False)
		hbox_quality.pack_start(label_res_u, False)
		
		align_quality = gtk.Alignment(.5, .5, 1, 1)
		align_quality.set_padding(5, 0, 15, 0)
		align_quality.add(hbox_quality)
		
		frame_quality = gtk.Frame(_("<b>Quality</b>"))
		frame_quality.get_label_widget().set_use_markup(True)
		frame_quality.set_shadow_type(gtk.SHADOW_NONE)
		frame_quality.add(align_quality)
		
		box.add(frame_quality)
		
		# Size
		
		self._radio_page = gtk.RadioButton(None, _("Render the whole page(s)"))
		self._radio_box = gtk.RadioButton(self._radio_page, _("Attempt to render a tight bounding box"))
		
		label_box = gtk.Label()
		label_box.set_markup(_("<small><u>Note:</u> This only works on one-page files and requires the <tt>\pagestyle{empty}</tt> command.</small>"))
		label_box.set_line_wrap(True)
		
		align_box = gtk.Alignment(.5, .5, 1, 1)
		align_box.set_padding(0, 0, 20, 0)
		align_box.add(label_box)
		
		vbox_size = gtk.VBox()
		vbox_size.set_spacing(2)
		vbox_size.add(self._radio_page)
		vbox_size.add(self._radio_box)
		vbox_size.add(align_box)
		
		align_size = gtk.Alignment(.5, .5, 1, 1)
		align_size.set_padding(5, 0, 15, 0)
		align_size.add(vbox_size)
		
		frame_size = gtk.Frame(_("<b>Output size</b>"))
		frame_size.get_label_widget().set_use_markup(True)
		frame_size.set_shadow_type(gtk.SHADOW_NONE)
		frame_size.add(align_size)
		
		box.add(frame_size)
		self.vbox.add(box)
		
		self.connect("response", self._onResponse)
		self._radio_png.connect("toggled", self._onFormatToggled)
		self._radio_jpg.connect("toggled", self._onFormatToggled)
		self._radio_gif.connect("toggled", self._onFormatToggled)
		self.set_default_response(gtk.RESPONSE_OK)
	
	def run(self):
		self.show_all()
		return gtk.Dialog.run(self)
	
	def _onFormatToggled(self, radio):
		self._label_png.set_sensitive(self._radio_png.get_active())
		self._combo_png.set_sensitive(self._radio_png.get_active())
	
	def _onResponse(self, widget, response):
		if response == gtk.RESPONSE_OK:
			if self._radio_png.get_active():
				self.format = const.PNG
			elif self._radio_jpg.get_active():
				self.format = const.JPG
			elif self._radio_gif.get_active():
				self.format = const.GIF
			self.pngMode = PNG_MODES[self._combo_png.get_active()][0]
			self.aaFactor = AA_FACTORS[self._combo_aa.get_active()]
			self.boundingBox = self._radio_box.get_active()
			self.resolution = self._spin_res.get_value()
		
