# -*- coding: utf-8 -*-

# SmartMenuToolButton.py
# This file is part of the Gedit LaTeX Plugin
#
# Copyright (C) 2006 Michael Zeising
#
# This program is free software; you can redistribute it and/or modify it under
# the terms of the GNU General Public Licence as published by the Free Software
# Foundation; either version 2 of the Licence, or (at your option) any later
# version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE.  See the GNU General Public Licence for more 
# details.
#
# You should have received a copy of the GNU General Public Licence along with
# this program; if not, write to the Free Software Foundation, Inc., 51 Franklin
# Street, Fifth Floor, Boston, MA  02110-1301, USA

import gtk

class SmartMenuToolButton(gtk.MenuToolButton):
	"""
	A MenuToolButton that switches the icon and action of its button to the
	ones last selected
	"""
	_active_item = None
	
	def __init__(self, image, label):
		gtk.MenuToolButton.__init__(self, image, label)
		# the MenuToolButton contains an HBox with a Button and a ToggleButton
		# (the arrow) in it
		# store a shortcut to the contained Button
		self._button = self.get_children()[0].get_children()[0]
		self._image = gtk.Image()
		
	def set_menu(self, menu, active_item_index):
		gtk.MenuToolButton.set_menu(self, menu)
		# connect to the menu items
		children = menu.get_children()
		for child in children:
			child.connect("activate", self._on_item_activated)
			
		# set the active item
		active_item = children[active_item_index]
		self._image.set_from_pixbuf(active_item.get_image().get_pixbuf())
		self._button.set_image(self._image)
		self._active_item = active_item
		
		# connect the button
		self.connect("clicked", self._on_button_clicked)
		
	def _on_item_activated(self, item):
		"""
		Called when a menu item is activated
		"""
		self._image.set_from_pixbuf(item.get_image().get_pixbuf())
		self._button.set_image(self._image)
		self._active_item = item

	def _on_button_clicked(self, button):
		"""
		Called when the MenuToolButton is clicked
		"""
		if self._active_item:
			self._active_item.emit("activate")
