# -*- coding: utf-8 -*-

# Symbols.py
# This file is part of the Gedit LaTeX Plugin
#
# Copyright (C) 2006 Michael Zeising
#
# This program is free software; you can redistribute it and/or modify it under
# the terms of the GNU General Public Licence as published by the Free Software
# Foundation; either version 2 of the Licence, or (at your option) any later
# version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE.  See the GNU General Public Licence for more 
# details.
#
# You should have received a copy of the GNU General Public Licence along with
# this program; if not, write to the Free Software Foundation, Inc., 51 Franklin
# Street, Fifth Floor, Boston, MA  02110-1301, USA

import gtk, os.path, glob
from gettext import gettext as _
import const

class Symbols(gtk.ScrolledWindow):
	_symbols = []

	def __init__(self, instance):
		gtk.ScrolledWindow.__init__(self)
		self.set_policy(gtk.POLICY_AUTOMATIC, gtk.POLICY_AUTOMATIC)
		
		self._instance = instance
		
		self.vbox = gtk.VBox()
		self.add_with_viewport(self.vbox)
		
		self.appendSymbolsPage(const.PATH + "/pixmaps/operators", const.PATH + "/pixmaps/operators.png")
		self.appendSymbolsPage(const.PATH + "/pixmaps/arrows", const.PATH + "/pixmaps/arrows.png")
		self.appendSymbolsPage(const.PATH + "/pixmaps/limiters", const.PATH + "/pixmaps/limiters.png")
		self.appendSymbolsPage(const.PATH + "/pixmaps/greek", const.PATH + "/pixmaps/greek.png")
		self.appendSymbolsPage(const.PATH + "/pixmaps/special", text=_("Special"))

		self.show_all()
		
	def appendSymbolsPage(self, path, icon_filename="", text=""):
		"""
		Appends a page of symbols to the notebook
			@param path: path to the symbol images
			@param icon: path to the page icon
			@param text: the text to be used as page icon
		"""
		model = gtk.ListStore(gtk.gdk.Pixbuf)
		
		filenames = glob.glob(path + '/*.png')
		filenames.sort()
		
		for filename in filenames:
			model.append([gtk.gdk.pixbuf_new_from_file(filename)])
			
		self._symbols.append(filenames)
		
		view = gtk.IconView(model)
		view.set_pixbuf_column(0)
		view.set_selection_mode(gtk.SELECTION_SINGLE)
		view.connect('selection-changed', self.onSymbolSelected, len(self._symbols) - 1)
		view.set_item_width(-1)			# use largest item width
		view.set_spacing(0)
		view.set_column_spacing(0)
		view.set_row_spacing(0)
		view.set_columns(-1)			# show as much as possible
		view.set_text_column(-1)
	
		#scroll = gtk.ScrolledWindow()
		#scroll.set_policy(gtk.POLICY_NEVER, gtk.POLICY_AUTOMATIC);
		#scroll.set_shadow_type(gtk.SHADOW_IN)
		#scroll.add(view)
		
		#if icon_filename:
		#	image = gtk.Image()
		#	image.set_from_file(icon_filename)
		#	self.append_page(scroll, image)
		#else:
		#	self.append_page(scroll, gtk.Label(text))
		
		self.vbox.pack_start(view, True)
		
	def onSymbolSelected(self, widget, symbol_list_index):
		"""
		Inserts a symbol
		"""
		try:
			index = widget.get_selected_items()[0][0]
		except IndexError:		# must be caught after unselect_all()
			return
		split_filename = os.path.basename(self._symbols[symbol_list_index][index]).split('.')
		symbol = split_filename[-2]
		self._instance.get_document().insert("\\" + symbol)
		widget.unselect_all()


class SymbolsOld(gtk.Notebook):
	_symbols = []

	def __init__(self, instance):
		self._instance = instance
		gtk.Notebook.__init__(self)
		
		self.appendSymbolsPage(const.PATH + "/pixmaps/operators", const.PATH + "/pixmaps/operators.png")
		self.appendSymbolsPage(const.PATH + "/pixmaps/arrows", const.PATH + "/pixmaps/arrows.png")
		self.appendSymbolsPage(const.PATH + "/pixmaps/limiters", const.PATH + "/pixmaps/limiters.png")
		self.appendSymbolsPage(const.PATH + "/pixmaps/greek", const.PATH + "/pixmaps/greek.png")
		self.appendSymbolsPage(const.PATH + "/pixmaps/special", text=_("Special"))

		self.show_all()
		
	def appendSymbolsPage(self, path, icon_filename="", text=""):
		"""
		Appends a page of symbols to the notebook
			@param path: path to the symbol images
			@param icon: path to the page icon
			@param text: the text to be used as page icon
		"""
		model = gtk.ListStore(gtk.gdk.Pixbuf)
		
		filenames = glob.glob(path + '/*.png')
		filenames.sort()
		
		for filename in filenames:
			model.append([gtk.gdk.pixbuf_new_from_file(filename)])
			
		self._symbols.append(filenames)
		
		view = gtk.IconView(model)
		view.set_pixbuf_column(0)
		view.set_selection_mode(gtk.SELECTION_SINGLE)
		view.connect('selection-changed', self.onSymbolSelected, len(self._symbols) - 1)
		view.set_item_width(-1)			# use largest item width
		view.set_spacing(0)
		view.set_column_spacing(0)
		view.set_row_spacing(0)
		view.set_columns(-1)			# show as much as possible
		view.set_text_column(-1)
	
		scroll = gtk.ScrolledWindow()
		scroll.set_policy(gtk.POLICY_NEVER, gtk.POLICY_AUTOMATIC);
		scroll.set_shadow_type(gtk.SHADOW_IN)
		scroll.add(view)
		
		if icon_filename:
			image = gtk.Image()
			image.set_from_file(icon_filename)
			self.append_page(scroll, image)
		else:
			self.append_page(scroll, gtk.Label(text))
	
	def onSymbolSelected(self, widget, symbol_list_index):
		"""
		Inserts a symbol
		"""
		try:
			index = widget.get_selected_items()[0][0]
		except IndexError:		# must be caught after unselect_all()
			return
		split_filename = os.path.basename(self._symbols[symbol_list_index][index]).split('.')
		symbol = split_filename[-2]
		self._instance.get_document().insert("\\" + symbol)
		widget.unselect_all()
