# -*- coding: utf-8 -*-

# TableDialog.py
# This file is part of the Gedit LaTeX Plugin
#
# Copyright (C) 2006 Michael Zeising
#
# This program is free software; you can redistribute it and/or modify it under
# the terms of the GNU General Public Licence as published by the Free Software
# Foundation; either version 2 of the Licence, or (at your option) any later
# version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE.  See the GNU General Public Licence for more 
# details.
#
# You should have received a copy of the GNU General Public Licence along with
# this program; if not, write to the Free Software Foundation, Inc., 51 Franklin
# Street, Fifth Floor, Boston, MA  02110-1301, USA

import gtk
from gettext import gettext as _
import const

class SmartRadioButton(gtk.RadioButton):
	def __init__(self, group=None, filename=None):
		gtk.RadioButton.__init__(self, group, None)
		image = gtk.Image()
		image.set_from_file(filename)
		self.add(image)
		image.show()
		

class TableDialog(gtk.Dialog):
	source = None
	package = None
	
	def __init__(self):
		gtk.Dialog.__init__(self, _("Insert Table or Matrix"), None, gtk.DIALOG_MODAL | gtk.DIALOG_DESTROY_WITH_PARENT, 
				(gtk.STOCK_CANCEL, gtk.RESPONSE_CANCEL, gtk.STOCK_OK, gtk.RESPONSE_OK))
		self.set_border_width(5)
		self.set_has_separator(False)
		self.vbox.set_spacing(5)
		
		# --- size ---
		
		label_rows = gtk.Label(_("_Rows:"))
		label_rows.set_use_underline(True)
		label_rows.set_alignment(0, .5)
		label_columns = gtk.Label(_("_Columns:"))
		label_columns.set_use_underline(True)
		label_columns.set_alignment(0, .5)
		
		self._spin_rows = gtk.SpinButton(gtk.Adjustment(1, 1, 1000, 1), 1)
		self._spin_columns = gtk.SpinButton(gtk.Adjustment(1, 1, 1000, 1), 1)
		
		hbox_size = gtk.HBox()
		hbox_size.set_border_width(5)
		hbox_size.set_spacing(10)
		hbox_size.add(label_rows)
		hbox_size.add(self._spin_rows)
		hbox_size.add(label_columns)
		hbox_size.add(self._spin_columns)
		
		self.vbox.add(hbox_size)
		
		# --- table vbox ---
		
		vbox_table = gtk.VBox()
		
		# --- matrix vbox ---
		
		# delimiters
		self._radio_delim_none = gtk.RadioButton(None, _("None"))
		self._radio_delim_normal = SmartRadioButton(self._radio_delim_none, const.PATH + "/pixmaps/parantheses.png")
		self._radio_delim_brackets = SmartRadioButton(self._radio_delim_none, const.PATH + "/pixmaps/brackets.png")
		self._radio_delim_braces = SmartRadioButton(self._radio_delim_none, const.PATH + "/pixmaps/braces.png")
		self._radio_delim_vert = SmartRadioButton(self._radio_delim_none, const.PATH + "/pixmaps/vbars.png")
		self._radio_delim_doublevert = SmartRadioButton(self._radio_delim_none, const.PATH + "/pixmaps/dvbars.png")
		
		table_delim = gtk.Table()
		table_delim.attach(self._radio_delim_none, 0, 1, 0, 1)
		table_delim.attach(self._radio_delim_normal, 1, 2, 0, 1)
		table_delim.attach(self._radio_delim_brackets, 2, 3, 0, 1)
		table_delim.attach(self._radio_delim_braces, 0, 1, 1, 2)
		table_delim.attach(self._radio_delim_vert, 1, 2, 1, 2)
		table_delim.attach(self._radio_delim_doublevert, 2, 3, 1, 2)
		
		align_delim = gtk.Alignment(.5, .5, 1, 1)
		align_delim.set_padding(3, 3, 15, 0)
		align_delim.add(table_delim)
		
		frame_delim = gtk.Frame(_("<b>_Delimiters</b>"))
		frame_delim.get_label_widget().set_use_markup(True)
		frame_delim.get_label_widget().set_use_underline(True)
		frame_delim.set_shadow_type(gtk.SHADOW_NONE)
		frame_delim.add(align_delim)
		
		# package
		self._radio_pack_array = gtk.RadioButton(None, _("Standard (array)"))
		self._radio_pack_ams = gtk.RadioButton(self._radio_pack_array, _("AMS (amsmath)"))
		self._radio_pack_ams.set_active(True)
		
		vbox_pack = gtk.VBox()
		vbox_pack.add(self._radio_pack_array)
		vbox_pack.add(self._radio_pack_ams)
		
		align_pack = gtk.Alignment(.5, .5, 1, 1)
		align_pack.set_padding(3, 3, 15, 0)
		align_pack.add(vbox_pack)
		
		frame_pack = gtk.Frame(_("<b>Package</b>"))
		frame_pack.get_label_widget().set_use_markup(True)
		frame_pack.set_shadow_type(gtk.SHADOW_NONE)
		frame_pack.add(align_pack)
		
		vbox_matrix = gtk.VBox()
		vbox_matrix.set_border_width(5)
		vbox_matrix.add(frame_delim)
		vbox_matrix.add(frame_pack)
		
		# --- main notebook ---
		self._notebook = gtk.Notebook()
		self._notebook.set_border_width(5)
		label_table = gtk.Label()
		label_table.set_markup("%s\n<small>%s</small>" % (_("Table"), _("general")))
		self._notebook.append_page(vbox_table, label_table)
		label_matrix = gtk.Label()
		label_matrix.set_markup("%s\n<small>%s</small>" % (_("Matrix"), _("mathematical")))
		self._notebook.append_page(vbox_matrix, label_matrix)
		
		self.vbox.add(self._notebook)
		
		self.connect("response", self._on_response)
		self.set_default_response(gtk.RESPONSE_OK)
	
	def run(self):
		self.show_all()
		return gtk.Dialog.run(self)
	
	def _on_response(self, dialog, response):
		if response == gtk.RESPONSE_OK:
			n_rows = self._spin_rows.get_value_as_int()
			n_columns = self._spin_columns.get_value_as_int()
		
			# grid
			placeholders = []
			for i in xrange(n_columns):
				placeholders.append(" x ")
			row = "&".join(placeholders)
			rows = []
			for i in xrange(n_rows):
				rows.append(row)
			grid = "\\\\\n".join(rows)
			
			if self._notebook.get_current_page():
				# matrix
				if self._radio_pack_array.get_active():		# array
					# delimiters
					if self._radio_delim_none.get_active():
						left_delim, right_delim = "", ""
					elif self._radio_delim_normal.get_active():
						left_delim, right_delim = r"\left(", r"\right)"
					elif self._radio_delim_brackets.get_active():
						left_delim, right_delim = r"\left[", r"\right]"
					elif self._radio_delim_braces.get_active():
						left_delim, right_delim = r"\left\lbrace", r"\right\rbrace"
					elif self._radio_delim_vert.get_active():
						left_delim, right_delim = r"\left\vert", r"\right\vert"
					elif self._radio_delim_doublevert.get_active():
						left_delim, right_delim = r"\left\Vert", r"\right\Vert"
					# columns
					columns = n_columns * "c"
					# assemble
					s = "%s \\begin{array}{%s}\n%s\n\\end{array} %s" % (left_delim, columns, grid, right_delim)
					#self.package = "array"
				elif self._radio_pack_ams.get_active():		# amsmath
					# delimiters
					if self._radio_delim_none.get_active():
						s = "\\begin{matrix}\n%s\n\\end{matrix}" % grid
					elif self._radio_delim_normal.get_active():
						s = "\\begin{pmatrix}\n%s\n\\end{pmatrix}" % grid
					elif self._radio_delim_brackets.get_active():
						s = "\\begin{bmatrix}\n%s\n\\end{bmatrix}" % grid
					elif self._radio_delim_braces.get_active():
						s = "\\begin{Bmatrix}\n%s\n\\end{Bmatrix}" % grid
					elif self._radio_delim_vert.get_active():
						s = "\\begin{vmatrix}\n%s\n\\end{vmatrix}" % grid
					elif self._radio_delim_doublevert.get_active():
						s = "\\begin{Vmatrix}\n%s\n\\end{Vmatrix}" % grid
					self.package = "amsmath"
				#if self._instance.get_document().environment != E_MATH:					# !!!
				#	s = "$%s$" % s
			else:
				# table
				columns = n_columns * "l"
				s = "\\begin{tabular}{%s}\n%s\n\\end{tabular}" % (columns, grid)
				#self.package = "array"
			self.source = s
